import json
from logging import Logger

import requests

from sidecar.const import DateTimeProvider, Const
from sidecar.kub_token_provider import KubTokenProvider
from sidecar.sandbox_start_time_updater import ISandboxStartTimeUpdater


class KubSandboxStartTimeUpdater(ISandboxStartTimeUpdater):
    def __init__(self, hostname: str, namespace: str,
                 apps_json: {},
                 date_time_provider: DateTimeProvider,
                 kub_token_provider: KubTokenProvider,
                 logger: Logger):
        super(KubSandboxStartTimeUpdater, self).__init__(date_time_provider, logger, apps_json)
        self.namespace = namespace
        self.hostname = hostname
        self.kub_token_provider = kub_token_provider
        self.date_time_provider = date_time_provider

    def on_health_check_done(self):
        s = requests.Session()
        s.headers['Content-Type'] = 'application/strategic-merge-patch+json'
        s.headers['Authorization'] = 'Bearer {}'.format(self.kub_token_provider.get_token())
        url = '{hostname}/api/v1/namespaces/{namespace}'.format(hostname=self.hostname,
                                                                namespace=self.namespace)
        data_json = {
            'metadata': {
                'annotations': {
                    Const.SANDBOX_START_TIME: str(self.date_time_provider.get_current_time_utc())
                }
            }
        }

        metadata_json = json.dumps(data_json)
        res = s.patch(url=url, data=metadata_json, verify=False)
        res.raise_for_status()

