import json
from abc import ABCMeta, abstractmethod
from logging import Logger

from sidecar.const import AppStatus, DateTimeProvider


class ISandboxStartTimeUpdater:
    __metaclass__ = ABCMeta

    def __init__(self, date_time_provider: DateTimeProvider, logger: Logger, apps_json: {}):
        self._date_time_provider = date_time_provider
        self._logger = logger
        self._apps_json = apps_json
        self._logger.info('apps_json: {}'.format(json.dumps(self._apps_json)))

    def update_sandbox_start_time_if_completed(self, app_name: str, status: str):
        if status == AppStatus.COMPLETED:
            self._apps_json[app_name] = self._apps_json[app_name] - 1
            self._logger.info('healthcheck completed for: {APP_NAME}. apps_json: {APPS_JSON}'
                              .format(APP_NAME=app_name, APPS_JSON=json.dumps(self._apps_json)))
            if not [o for o in self._apps_json.values() if o != 0]:
                curr_time = self._date_time_provider.get_current_time_utc()
                self._logger.info('health check done time: {}'.format(curr_time))
                self.on_health_check_done()

    @abstractmethod
    def on_health_check_done(self):
        NotImplementedError
